export declare const AccessEntryType: {
    /**
     * Standard Access Entry Workflow. Allows users to input a username and kubernetesGroup, and to associate access policies.
     */
    readonly Standard: "STANDARD";
    /**
     * For IAM roles used with AWS Fargate profiles.
     */
    readonly FargateLinux: "FARGATE_LINUX";
    /**
     * For IAM roles associated with self-managed Linux node groups. Allows the nodes to join the cluster.
     */
    readonly EC2Linux: "EC2_LINUX";
    /**
     * For IAM roles associated with self-managed Windows node groups. Allows the nodes to join the cluster.
     */
    readonly EC2Windows: "EC2_WINDOWS";
    /**
     * For IAM roles associated with EC2 instances that need access policies. Allows the nodes to join the cluster.
     */
    readonly EC2: "EC2";
    /**
     * @deprecated Use `Standard` instead`
     */
    readonly STANDARD: "STANDARD";
    /**
     * @deprecated Use `FargateLinux` instead`
     */
    readonly FARGATE_LINUX: "FARGATE_LINUX";
    /**
     * @deprecated Use `EC2Linux` instead`
     */
    readonly EC2_LINUX: "EC2_LINUX";
    /**
     * @deprecated Use `EC2Windows` instead`
     */
    readonly EC2_WINDOWS: "EC2_WINDOWS";
};
/**
 * The type of the new access entry. Valid values are STANDARD, FARGATE_LINUX, EC2_LINUX, and EC2_WINDOWS.
 * Defaults to STANDARD which provides the standard workflow. EC2_LINUX and EC2_WINDOWS types disallow users to input a kubernetesGroup, and prevent associating access policies.
 */
export type AccessEntryType = (typeof AccessEntryType)[keyof typeof AccessEntryType];
export declare const AmiType: {
    /**
     * @deprecated Amazon Linux 2 is deprecated. Please use Amazon Linux 2023 instead.
See for more details: https://docs.aws.amazon.com/eks/latest/userguide/al2023.html
     */
    readonly AL2X86_64: "AL2_x86_64";
    /**
     * @deprecated Amazon Linux 2 is deprecated. Please use Amazon Linux 2023 instead.
See for more details: https://docs.aws.amazon.com/eks/latest/userguide/al2023.html
     */
    readonly AL2X86_64GPU: "AL2_x86_64_GPU";
    /**
     * @deprecated Amazon Linux 2 is deprecated. Please use Amazon Linux 2023 instead.
See for more details: https://docs.aws.amazon.com/eks/latest/userguide/al2023.html
     */
    readonly AL2Arm64: "AL2_ARM_64";
    readonly AL2023X86_64Standard: "AL2023_x86_64_STANDARD";
    readonly AL2023Arm64Standard: "AL2023_ARM_64_STANDARD";
    readonly AL2023X86_64Nvidia: "AL2023_x86_64_NVIDIA";
    readonly BottlerocketArm64: "BOTTLEROCKET_ARM_64";
    readonly BottlerocketX86_64: "BOTTLEROCKET_x86_64";
    readonly BottlerocketArm64Nvidia: "BOTTLEROCKET_ARM_64_NVIDIA";
    readonly BottlerocketX86_64Nvidia: "BOTTLEROCKET_x86_64_NVIDIA";
};
/**
 * Predefined AMI types for EKS optimized AMIs. Can be used to select the latest EKS optimized AMI for a node group.
 */
export type AmiType = (typeof AmiType)[keyof typeof AmiType];
export declare const AuthenticationMode: {
    /**
     * Only aws-auth ConfigMap will be used for authenticating to the Kubernetes API.
     *
     * @deprecated The aws-auth ConfigMap is deprecated. The recommended method to manage access to Kubernetes APIs is Access Entries with the AuthenticationMode API.
For more information and instructions how to upgrade, see https://docs.aws.amazon.com/eks/latest/userguide/migrating-access-entries.html.
     */
    readonly ConfigMap: "CONFIG_MAP";
    /**
     * Only Access Entries will be used for authenticating to the Kubernetes API.
     */
    readonly Api: "API";
    /**
     * Both aws-auth ConfigMap and Access Entries can be used for authenticating to the Kubernetes API.
     *
     * @deprecated The aws-auth ConfigMap is deprecated. The recommended method to manage access to Kubernetes APIs is Access Entries with the AuthenticationMode API.
For more information and instructions how to upgrade, see https://docs.aws.amazon.com/eks/latest/userguide/migrating-access-entries.html.
     */
    readonly ApiAndConfigMap: "API_AND_CONFIG_MAP";
    /**
     * @deprecated Use `ConfigMap` instead
     */
    readonly CONFIG_MAP: "CONFIG_MAP";
    /**
     * @deprecated Use `Api` instead
     */
    readonly API: "API";
    /**
     * @deprecated Use `ApiAndConfigMap` instead
     */
    readonly API_AND_CONFIG_MAP: "API_AND_CONFIG_MAP";
};
/**
 * The authentication mode of the cluster. Valid values are `CONFIG_MAP`, `API` or `API_AND_CONFIG_MAP`.
 *
 * See for more details:
 * https://docs.aws.amazon.com/eks/latest/userguide/grant-k8s-access.html#set-cam
 */
export type AuthenticationMode = (typeof AuthenticationMode)[keyof typeof AuthenticationMode];
export declare const ClusterNodePools: {
    /**
     * This NodePool has a `CriticalAddonsOnly` taint. Many EKS addons, such as CoreDNS, tolerate this taint. Use this system node pool to segregate cluster-critical applications. Supports both `amd64` and `arm64` architectures.
     */
    readonly System: "system";
    /**
     * This NodePool provides support for launching nodes for general purpose workloads in your cluster. Only supports `amd64` architecture.
     */
    readonly GeneralPurpose: "general-purpose";
};
/**
 * Built-in node pools of EKS Auto Mode. For more details see: https://docs.aws.amazon.com/eks/latest/userguide/set-builtin-node-pools.html
 */
export type ClusterNodePools = (typeof ClusterNodePools)[keyof typeof ClusterNodePools];
export declare const OperatingSystem: {
    /**
     * EKS optimized OS based on Amazon Linux 2 (AL2).
     *
     * @deprecated Amazon Linux 2 is deprecated. Please use Amazon Linux 2023 instead.
See for more details: https://docs.aws.amazon.com/eks/latest/userguide/al2023.html
     */
    readonly AL2: "AL2";
    /**
     * EKS optimized OS based on Amazon Linux 2023 (AL2023).
     * See for more details: https://docs.aws.amazon.com/eks/latest/userguide/eks-optimized-ami.html
     */
    readonly AL2023: "AL2023";
    /**
     * EKS optimized Container OS based on Bottlerocket.
     * See for more details: https://docs.aws.amazon.com/eks/latest/userguide/eks-optimized-ami-bottlerocket.html
     */
    readonly Bottlerocket: "Bottlerocket";
    /**
     * The recommended EKS optimized OS. Currently Amazon Linux 2023 (AL2023).
     * This will be kept up to date with AWS' recommendations for EKS optimized operating systems.
     *
     * See for more details: https://docs.aws.amazon.com/eks/latest/userguide/eks-optimized-ami.html
     */
    readonly RECOMMENDED: "AL2023";
};
/**
 * The type of EKS optimized Operating System to use for node groups.
 *
 * See for more details:
 * https://docs.aws.amazon.com/eks/latest/userguide/eks-optimized-amis.html
 */
export type OperatingSystem = (typeof OperatingSystem)[keyof typeof OperatingSystem];
export declare const ResolveConflictsOnCreate: {
    /**
     * If the self-managed version of the add-on is installed on your cluster, Amazon EKS doesn't change the value. Creation of the add-on might fail.
     */
    readonly None: "NONE";
    /**
     * If the self-managed version of the add-on is installed on your cluster and the Amazon EKS default value is different than the existing value, Amazon EKS changes the value to the Amazon EKS default value.
     */
    readonly Overwrite: "OVERWRITE";
};
/**
 * How to resolve field value conflicts when migrating a self-managed add-on to an Amazon EKS add-on. Valid values are `NONE` and `OVERWRITE`. For more details see the [CreateAddon](https://docs.aws.amazon.com/eks/latest/APIReference/API_CreateAddon.html) API Docs.
 */
export type ResolveConflictsOnCreate = (typeof ResolveConflictsOnCreate)[keyof typeof ResolveConflictsOnCreate];
export declare const ResolveConflictsOnUpdate: {
    /**
     * Amazon EKS doesn't change the value. The update might fail.
     */
    readonly None: "NONE";
    /**
     * Amazon EKS overwrites the changed value back to the Amazon EKS default value.
     */
    readonly Overwrite: "OVERWRITE";
    /**
     * Amazon EKS preserves the value. If you choose this option, we recommend that you test any field and value changes on a non-production cluster before updating the add-on on your production cluster.
     */
    readonly Preserve: "PRESERVE";
};
/**
 * How to resolve field value conflicts for an Amazon EKS add-on if you've changed a value from the Amazon EKS default value. Valid values are `NONE`, `OVERWRITE`, and `PRESERVE`. For more details see the [UpdateAddon](https://docs.aws.amazon.com/eks/latest/APIReference/API_UpdateAddon.html) API Docs.
 */
export type ResolveConflictsOnUpdate = (typeof ResolveConflictsOnUpdate)[keyof typeof ResolveConflictsOnUpdate];
